@@ -1,10 +1,10 @@
 .onLoad <- function(lib, pkg){
-    require("methods", character = TRUE, quietly = TRUE)
-    require("distr", character = TRUE, quietly = TRUE)
-    require("distrEx", character = TRUE, quietly = TRUE)
-    require("RandVar", character = TRUE, quietly = TRUE)
-    require("distrMod", character = TRUE, quietly = TRUE)
-    require("RobAStBase", character = TRUE, quietly = TRUE)
+#    require("methods", character = TRUE, quietly = TRUE)
+#    require("distr", character = TRUE, quietly = TRUE)
+#    require("distrEx", character = TRUE, quietly = TRUE)
+#    require("RandVar", character = TRUE, quietly = TRUE)
+#    require("distrMod", character = TRUE, quietly = TRUE)
+#    require("RobAStBase", character = TRUE, quietly = TRUE)
 }
 
 
